@@ -395,12 +395,13 @@ def show(
             pts = (pts * np.array([[w, h]])).astype(np.uint16).tolist()
         ax.scatter(*zip(*pts), c=kwargs.pop("pts_color", "red"))
     if conns is not None:
-        for i in range(len(conns)):
-            if len(conns[i]) == 2:
-                start_ix, end_ix = conns[i]
+        conn_colors = kwargs.pop("conn_colors", ["cyan"] * len(conns))
+        for ix in range(len(conns)):
+            if len(conns[ix]) == 2:
+                start_ix, end_ix = conns[ix]
                 meta = 1
             else:
-                start_ix, end_ix, meta = conns[i]
+                start_ix, end_ix, meta = conns[ix]
             _x, _y = bbs[start_ix].xc, bbs[start_ix].yc
             _X, _Y = bbs[end_ix].xc, bbs[end_ix].yc
             _dx, _dy = _X - _x, _Y - _y
@@ -411,7 +412,7 @@ def show(
                 _jitter(_dx),
                 _jitter(_dy),
                 length_includes_head=True,
-                color="cyan",
+                color=conn_colors[ix],
                 head_width=4,
                 head_length=4,
                 width=meta * 2,
